@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -13,6 +13,8 @@
 namespace Composer\EventDispatcher;
 
 /**
+ * Thrown when a script running an external process exits with a non-0 status code
+ *
  * @author Jordi Boggiano <j.boggiano@seld.be>
  */
 class ScriptExecutionException extends \RuntimeException
