@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -20,34 +20,34 @@ namespace Composer\Package;
 class CompletePackage extends Package implements CompletePackageInterface
 {
     /** @var mixed[] */
-    protected $repositories = array();
+    protected $repositories = [];
     /** @var string[] */
-    protected $license = array();
+    protected $license = [];
     /** @var string[] */
-    protected $keywords = array();
+    protected $keywords = [];
     /** @var array<array{name?: string, homepage?: string, email?: string, role?: string}> */
-    protected $authors = array();
+    protected $authors = [];
     /** @var ?string */
     protected $description = null;
     /** @var ?string */
     protected $homepage = null;
     /** @var array<string, string[]> Map of script name to array of handlers */
-    protected $scripts = array();
-    /** @var array{issues?: string, forum?: string, wiki?: string, source?: string, email?: string, irc?: string, docs?: string, rss?: string, chat?: string} */
-    protected $support = array();
+    protected $scripts = [];
+    /** @var array{issues?: string, forum?: string, wiki?: string, source?: string, email?: string, irc?: string, docs?: string, rss?: string, chat?: string, security?: string} */
+    protected $support = [];
     /** @var array<array{url?: string, type?: string}> */
-    protected $funding = array();
+    protected $funding = [];
     /** @var bool|string */
     protected $abandoned = false;
     /** @var ?string */
     protected $archiveName = null;
     /** @var string[] */
-    protected $archiveExcludes = array();
+    protected $archiveExcludes = [];
 
     /**
      * @inheritDoc
      */
-    public function setScripts(array $scripts)
+    public function setScripts(array $scripts): void
     {
         $this->scripts = $scripts;
     }
@@ -55,7 +55,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getScripts()
+    public function getScripts(): array
     {
         return $this->scripts;
     }
@@ -63,7 +63,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setRepositories(array $repositories)
+    public function setRepositories(array $repositories): void
     {
         $this->repositories = $repositories;
     }
@@ -71,7 +71,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getRepositories()
+    public function getRepositories(): array
     {
         return $this->repositories;
     }
@@ -79,7 +79,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setLicense(array $license)
+    public function setLicense(array $license): void
     {
         $this->license = $license;
     }
@@ -87,7 +87,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getLicense()
+    public function getLicense(): array
     {
         return $this->license;
     }
@@ -95,7 +95,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setKeywords(array $keywords)
+    public function setKeywords(array $keywords): void
     {
         $this->keywords = $keywords;
     }
@@ -103,7 +103,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getKeywords()
+    public function getKeywords(): array
     {
         return $this->keywords;
     }
@@ -111,7 +111,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setAuthors(array $authors)
+    public function setAuthors(array $authors): void
     {
         $this->authors = $authors;
     }
@@ -119,7 +119,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getAuthors()
+    public function getAuthors(): array
     {
         return $this->authors;
     }
@@ -127,7 +127,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setDescription($description)
+    public function setDescription(?string $description): void
     {
         $this->description = $description;
     }
@@ -135,7 +135,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getDescription()
+    public function getDescription(): ?string
     {
         return $this->description;
     }
@@ -143,7 +143,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setHomepage($homepage)
+    public function setHomepage(?string $homepage): void
     {
         $this->homepage = $homepage;
     }
@@ -151,7 +151,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getHomepage()
+    public function getHomepage(): ?string
     {
         return $this->homepage;
     }
@@ -159,7 +159,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setSupport(array $support)
+    public function setSupport(array $support): void
     {
         $this->support = $support;
     }
@@ -167,7 +167,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getSupport()
+    public function getSupport(): array
     {
         return $this->support;
     }
@@ -175,7 +175,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setFunding(array $funding)
+    public function setFunding(array $funding): void
     {
         $this->funding = $funding;
     }
@@ -183,7 +183,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getFunding()
+    public function getFunding(): array
     {
         return $this->funding;
     }
@@ -191,7 +191,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function isAbandoned()
+    public function isAbandoned(): bool
     {
         return (bool) $this->abandoned;
     }
@@ -199,7 +199,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setAbandoned($abandoned)
+    public function setAbandoned($abandoned): void
     {
         $this->abandoned = $abandoned;
     }
@@ -207,7 +207,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getReplacementPackage()
+    public function getReplacementPackage(): ?string
     {
         return \is_string($this->abandoned) ? $this->abandoned : null;
     }
@@ -215,7 +215,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setArchiveName($name)
+    public function setArchiveName(?string $name): void
     {
         $this->archiveName = $name;
     }
@@ -223,7 +223,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getArchiveName()
+    public function getArchiveName(): ?string
     {
         return $this->archiveName;
     }
@@ -231,7 +231,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function setArchiveExcludes(array $excludes)
+    public function setArchiveExcludes(array $excludes): void
     {
         $this->archiveExcludes = $excludes;
     }
@@ -239,7 +239,7 @@ class CompletePackage extends Package implements CompletePackageInterface
     /**
      * @inheritDoc
      */
-    public function getArchiveExcludes()
+    public function getArchiveExcludes(): array
     {
         return $this->archiveExcludes;
     }
